package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,``P`!````,!8``#0```!8P0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````E*X`
M`)2N```%`````!````$```#0O0``T,T``-#-``!``@``A!(```8`````$```
M`@```-R]``#<S0``W,T``/````#P````!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&30GP``T)\``-"?``#L````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DT+T`
M`-#-``#0S0``,`(``#`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`"$O"D+I'@7?6X^O+,2P@O^$'ZC<1````3`````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````3````%````!4````50``
M`%L```!<````70```%\```!@`````````&(```!D````90```&8`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"=`@``````
M```````2````4@,`````````````$@```/(!`````````````!(````1````
M```````````@````:P,`````````````$0```-$#`````````````!(```#J
M`@`````````````1````0P,`````````````$@```!D!`````````````!(`
M``"X`@`````````````2````O```````````````$@```(L!````````````
M`!(```"D`@`````````````2````F```````````````$@```!0!````````
M`````!(```!U`P`````````````2````\0(`````````````$@````D!````
M`````````!$```!L`@`````````````2````;P$`````````````$@```.L`
M`````````````!$````!`P`````````````2````^`(`````````````$@``
M`#T!`````````````!(```#*```````````````2````)@,`````````````
M(@```+D!`````````````!(````[`@`````````````2````Z@$`````````
M````$@```(@"`````````````!(```"F`0`````````````2````>0(`````
M````````$@```+(!`````````````!(```!+`0`````````````2````"`,`
M````````````$@```"T``````````````"````!-`@`````````````2````
MQ`$`````````````$0```!4#`````````````!(```!X```````````````2
M````E@(`````````````$@```%D#`````````````!(```#C`0``````````
M```2````IP``````````````$@```&0!`````````````!(```!S`@``````
M```````2````6@(`````````````$@```"H!`````````````!(````+`@``
M```````````2````@0(`````````````$@```&H``````````````!(````>
M`0`````````````2````OP(`````````````$@```)L!`````````````!(`
M``#X```````````````2````2P,`````````````$@```(\"````````````
M`!(```!L`P`````````````A````?0$`````````````$@```(<`````````
M`````!(````\```````````````@````W```````````````$@```%L!````
M`````````!(````<`P`````````````2````J@(`````````````$@```%``
M`````````````"````!2`@`````````````2````;0,`````````````$0``
M`.`"`````````````!(```#W`0`````````````2````S0(`````````````
M$@```!P"`````````````!(```!C`@`````````````2````V`(`````````
M````$@```#4#`````````````!(```#:`P``P%T``'<````2``T`J`,```1?
M````````$@`.`/\#``!03```:0T``!(`#0!F`P``\!,``$`"```2``T`K@,`
M`#!%```%````$@`-`&4$``!`10``[P$``!(`#0!?!```Q!$````````2``H`
MD@0``,!9``#V`P``$@`-`(T#```0T````````!``&`#F`P``,$<``"(````2
M``T`+`(``!Q?```$````$0`/`)D#``!4X````````!``&`!=!```P$,``#L`
M```2``T`<@0``/!*``!:`0``$@`-`(0$```P2@``>0```!(`#0`,!````-``
M```````0`!<`\P,``&!'``#H````$@`-`(8#```0T````````!``%P`_!```
M#-````0````1`!<`G@,``.!>```"````$@`-`"\$``"`7@``70```!(`#0`2
M!```,!8````````2``T`#@0```#0````````(``7`$D$```87P``!````!$`
M#P"_`P``L$H``#0````2``T`&00``&!$``#)````$@`-`%`$``!02```V0$`
M`!(`#0``;&EB<&5R;"YS;RXU+C(R`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`
M4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`
M4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N
M`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`
M;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A
M=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E
M<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'5N;&EN
M:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S
M=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H
M:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`
M<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T
M`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`
M<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W-T86-K7V-H
M:U]F86EL`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN
M:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT
M;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]F<%]H=P!P87)?:6YI=%]E;G8`>'-?
M:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C
M;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR`$=,24)#7S(N
M,`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C$N,P!'3$E"0U\R
M+C0````"``(``P````(``@`"``(``@`"```````"```````$``(````"````
M```"``(```````4````&``<``@````(``@````@````"`````@````(``@`'
M```````"``(````#``(```````@```````(``@`"```````````````)``@`
M```"``(`"0`#``D``P`"``(`"``!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``(`TP$``!`````P````
M$FEI#0``!P"H!```$````!!I:0T```,`L@0````````!``8`(@(``!``````
M````$FEI#0``"0"H!```$````'09:0D```@`O`0``!````!R&6D)```&`,@$
M```0````<Q]I"0``!0#4!```$````!1I:0T```0`X`0``!`````0:6D-```"
M`+($````````T,T```@```#4S0``"````+3/```(````!-````@````,T```
M"````-C.```&`0``W,X```8"``#@S@``!@,``.3.```&!```Z,X```8&``#L
MS@``!@<``/#.```&"```],X```8)``#XS@``!@H``/S.```&"P```,\```8,
M```$SP``!@T```C/```&#@``#,\```8/```0SP``!A```!3/```&$0``&,\`
M``82```<SP``!A,``"#/```&%```),\```85```HSP``!A8``"S/```&%P``
M,,\```88```TSP``!AD``#C/```&&@``/,\```8;``!`SP``!AP``$3/```&
M'0``2,\```8>``!,SP``!A\``%#/```&(```5,\```8A``!8SP``!B(``%S/
M```&(P``8,\```8D``!DSP``!B4``&C/```&)@``;,\```8G``!PSP``!B@`
M`'3/```&*0``>,\```8J``!\SP``!BL``(#/```&+```A,\```8M``"(SP``
M!BX``(S/```&+P``D,\```8P``"4SP``!C$``)C/```&,@``G,\```8S``"@
MSP``!C0``*3/```&-0``J,\```8V``"LSP``!C<``+#/```&.```N,\```8Y
M``"\SP``!CL``,#/```&/```Q,\```8]``#(SP``!CX``,S/```&/P``T,\`
M``9```#4SP``!D$``-C/```&0@``W,\```9#``#@SP``!D0``.3/```&10``
MZ,\```9&``#LSP``!D<``/#/```&2```],\```9)``#XSP``!DH``/S/```&
M2P``4X/L".BC!```@</_O```BX.4````A<!T!>@&`0``@\0(6\,`````````
M``#_LP0```#_HP@`````````_Z,,````9I#_HQ````!FD/^C%````&:0_Z,<
M````9I#_HR0```!FD/^C*````&:0_Z,L````9I#_HS````!FD/^C.````&:0
M_Z,\````9I#_HT````!FD/^C1````&:0_Z-(````9I#_HU````!FD/^C5```
M`&:0_Z-<````9I#_HV````!FD/^C9````&:0_Z-H````9I#_HVP```!FD/^C
M<````&:0_Z-T````9I#_HW@```!FD/^C?````&:0_Z.`````9I#_HX0```!F
MD/^CB````&:0_Z.,````9I#_HY````!FD/^CE````&:0_Z.8````9I#_HZ``
M``!FD/^CI````&:0_Z.H````9I#_HZP```!FD/^CL````&:0_Z.T````9I#_
MH[@```!FD/^CO````&:0_Z/`````9I#_H\@```!FD/^CS````&:0_Z/0````
M9I#_H]0```!FD/^CV````&:0_Z/<````9I#_H^````!FD/^CY````&:0_Z/L
M````9I#_H_````!FD/^C_````&:0_Z,``0``9I#_HP0!``!FD/^C"`$``&:0
M_Z,0`0``9I#_HQ@!``!FD/^C'`$``&:0_Z,@`0``9I#_HR0!``!FD/^C*`$`
M`&:0_Z,L`0``9I#_HS`!``!FD(U,)`2#Y/#_<?Q5B>575E-1B<[H:`(``('#
MQ+H``(/L+(M!!(E%U(M!"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z,K^__^+
M@\0```"#Q`Q04/^S]````.CT20``BX-8````@\00@#@`#X0F`0``B[M,````
M@^P,_S?H4O___X"("@,```):_S?H0____X"("@,```&+!H/$$(/`!3W___\_
M#X=9`0``@^P,P>`"4.@=_O__BWW4BS:#Q!")@W@1``#'@WP1```$````BQ>#
M_@&)$(V3+Y+__XE0!(N30`$``(E0"(V3,I+__XE0#+H!````?A*-="8`BPR7
MB4R0#(/"`3GR=?*#[`S'1+`,`````(/&`VH`4(V#-'7__U90_[.$$0``Z$[^
M__^#Q""%P(G&#X26````@^P,_[.$$0``C7W@Z#C]__^-@_.0__^)^NC[)P``
M@\00A<`/A(4```"#[`S_LX01``#H\OS__^CM_?__@\00B?"+?>1E,ST4````
M#X6I````C67P65M>7UV-8?S#Z!?]__^%P(F#A!$```^$CP```(/L#%#HJ/S_
M_XN[3````%G_-^@2_O__@\00QH!Y!0```.FG_O__@^P,_[.$$0``Z,W]__^#
MQ!")QNE2____BX.`$0``A<!T)8/L#%#HV$<``(/$$.E@____4%"-@Z.0____
MLYP```!0Z!S]__^-@ZB0__^)^N@O)P``A<")@X`1```/A#'____KONC*2```
M@^P,:@'HP/S__S'M7HGA@^3P4%12Z"(```"!PXRX``"-@Q20__]0C8.TC___
M4%%6_[/H````Z*_\___TBQPDPV:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0
MZ!<!``"!PD>X``"-BD0!``"-@D<!```IR(/X!G87BX(8````A<!T#56)Y8/L
M%%'_T(/$$,GSPXGVC;PG`````.C7````@<('N```58V*1`$``(V"1`$``(GE
M4RG(P?@"@^P$B</!ZQ\!V-'X=!2+D@P!``"%TG0*@^P(4%'_TH/$$(M=_,G#
MB?:-O"<`````58GE4^A7____@<.SMP``@^P$@+M4`0```'4GBX-L````A<!T
M$8/L#/^S.`$``.A5^___@\00Z#7____&@U0!```!BUW\R<.)]HV\)P````#H
M-P```('"9[<``(V"#/___XL(A<EU">E$____C70F`(N2^````(72=.U5B>6#
M[!10_]*#Q!#)Z23___^+%"3#55>-:#A64X'L#`,``(E$)$R-A"2`````B7PD
M%&6+%10```")E"3\`@``,=*-E"0``0``B>^)="00B<6)5"0(D(L'BU<$,=O'
M1?P`````@\<(@\40#\B)UHG1B47HB=#!YAC!X`B)VB4``/\`"?")QHG(#ZS0
M&,'J&`G&B<B)%"0/K-@()0#_```)\(E%\(L$)(E%]#EL)`AUIHV$).````"-
ME"3@`@``B<6)%"2-=@"+50"+102#Q0@S5=`S1=0S5:`S1:0S59`S193'110`
M````B<>)T8G0#ZSY'P'0"<&)31`[+"1UR(M$)$PQTHMX"(MP$(MH#(L(BU@$
MB7PD&(MX%(DT)(MP&(EL)!R+:"2)?"0$BW@<B70D"(G.B4PD$,'F!8EL)%R)
M7"04B7PD#(MX((GU#ZS9&XE\)%@)S8M\)%@#?"1XB>B+;"1<$VPD?(GY@<&9
M>8):B>N#TP`!R(M,)!@1VHL<)(E$)"")5"0DBU0D"(G=,=6)[R'/B?J+?"0(
MBW0D((ML)!R+3"0,BQPDQT0D)``````Q^HM\)!C'1"0T``````'6B70D((ET
M)"B)^L'B'@^L[P*)U8M4)`@)_0.4)(`````3C"2$````B6PD,(ML)#")T`69
M>8):B<J+3"00@](`,=V)1"0XB>^)5"0\BT0D("'/QT0D/`````")^HL\)(G&
M,?J)QXM$)!")T8M4)"0#3"0XP>8%B70D.(MT)#@/K-<;BU0D%(G+B<$)_@'S
MP>$>,?\/K-`"B<V+5"0PB5PD4`G%B=Z);"0XBVPD(/?5(>J+;"0H(VPD.,=$
M)"P`````QT0D1`````")Z(G5BU0D)`G%BP0D`X0DB````(GIQT0D)``````%
MF7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)$`+;"1`BT0D(`'IB4PD*(E,
M)&")P<'A'@^LT`*)S8M4)#@)Q8M$)#");"1`B=WWU2'JBVPD4"-L)$`)Z@.$
M))````")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)1"0P
M"VPD,`'IB4PD4(E,)"")V0^L_@+!X1Z)S0GUB6PD,(ML)"B+5"1`BW0D.,=$
M)#0`````QT0D/`````#WU2'JBVPD8"-L)#")Z(G5BU0D)`G%`[0DF````(GI
MB?`%F7F"6@'!BT0D((G&B<?!Y@6)="0XBW0D.`^LUQN+5"0LQT0D+``````)
M_HGPB<X!QHM$)"@Q_XET)&")P<'A'@^LT`*)S8M4)#`)Q8M$)$");"0XBVPD
M(/?5(>J+;"10(VPD.`GJ`X0DH````(G1!9EY@EH!P8GPP>`%B40D*(GPBVPD
M*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)%")3"0HB<&+5"0DP>$>QT0D)`````")
MS<=$)$0`````QT0D-``````/K-`"B?()Q??2(U0D.(EL)$"+;"1@(VPD0(M$
M)#`)Z@.$)*@```")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^L
MT!N+5"1`B40D,`ML)#`!Z8E,)"")3"1@B?'!X1X/K/X"B<T)]8MT)#B);"0P
MBVPD*/?5(>J+;"10(VPD,(GHB=6+5"0D"<4#M"2P````B>F)\`69>8):`<&+
M1"0@B<:)Q\'F!8ET)#B+="0X#ZS7&PG^B?")S@'&,?^)="10BT0D*(M4)"S'
M1"0L`````,=$)#P`````QT0D1`````")P<'A'@^LT`*)S8M4)#`)Q8M$)$")
M;"0XBVPD(/?5(>J+;"1@(VPD.`GJ`X0DN````(G1BU0D)`69>8):`<&)\,'@
M!8E$)"B)\(ML)"@/K/@;B40D0`ML)$"+1"0@`>F)3"0HB4PD8(G!P>$>#ZS0
M`HG-B?()Q??2(U0D.(EL)$"+;"10(VPD0(M$)#`)Z@.$),````")T8M4)"P%
MF7F"6@'!BT0D*,'@!8E$)""+1"0H#ZS0&XE$)#"+;"0@"VPD,(M4)$#'1"0D
M`````,=$)#0`````QT0D/``````!Z8E,)"")3"10B?'!X1X/K/X"B<T)]8MT
M)#B);"0PBVPD*/?5(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3(````B>F)\`69
M>8):`<&+1"0@B<:)Q\'F!8ET)#B+="0X#ZS7&XM4)"P)_HGPB<X!QHM$)"@Q
M_XET)&")P<'A'@^LT`*)S8M4)#`)Q8M$)$");"0XBVPD(/?5(>J+;"10(VPD
M.`GJ`X0DT````(G1!9EY@EH!P8GPP>`%B40D*(GP#ZSX&XE$)$"+;"0H"VPD
M0(M$)""+5"0DQT0D+`````#'1"1$`````,=$)"0`````QT0D-``````!Z8E,
M)"B)3"10B<'!X1X/K-`"B<V)\@G%]](C5"0XB6PD0(ML)&`C;"1`BT0D,`GJ
M`X0DV````(G1BU0D+`69>8):`<&+1"0HP>`%B40D((M$)"B+;"0@#ZS0&XM4
M)$")1"0P"VPD,`'IB4PD8(E,)"")\<'A'@^L_@*)S0GUBW0D.(EL)#"+;"0H
M]]4AZHML)%`C;"0PB>B)U0G%`[0DX````(M4)"2)Z<=$)#P`````QT0D1```
M``")\`69>8):`<&+1"0@B<:)Q\'F!8ET)#B+="0X#ZS7&XM4)"S'1"0L````
M``G^B?")S@'&BT0D*#'_B70D4(G!P>$>#ZS0`HG-BU0D,`G%BT0D0(EL)#B+
M;"0@]]4AZHML)&`C;"0X">H#A"3H````B=&+5"0D!9EY@EH!P8GPP>`%B40D
M*(GPBVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)&")3"0HB<'!X1X/K-`"B<V)
M\@G%]](C5"0XB6PD0(ML)%`C;"1`BT0D,,=$)"0`````QT0D-`````#'1"0\
M``````GJ`X0D\````(G1BU0D+`69>8):`<&+1"0HP>`%B40D((M$)"B+;"0@
M#ZS0&XM4)$")1"0P"VPD,`'IB4PD((E,)%")\<'A'@^L_@*)S0GUBW0D.(EL
M)#"+;"0H]]4AZHML)&`C;"0PB>B)U8M4)"0)Q0.T)/@```")Z8GP!9EY@EH!
MP8M$)"")QHG'P>8%B70D.(MT)#@/K-<;BU0D+`G^B?")S@'&BT0D*#'_B70D
M8(G!P>$>#ZS0`HG-"<6);"0XBVPD((M4)#"+1"1`QT0D+`````#WU2'JBVPD
M4"-L)#@)Z@.$)``!``")T8M4)"3'1"0D``````69>8):`<&)\,'@!8E$)"B)
M\(ML)"@/K/@;B40D0`ML)$"+1"0@`>F)3"0HB4PD4(G!P>$>#ZS0`HG-B?()
MQ??2(U0D.(EL)""+;"1@(VPD((M$)#`)Z@.$)`@!``")T8M4)"P%F7F"6@'!
MBT0D*,'@!8E$)#"+1"0HBVPD,`^LT!N)\HE$)$`+;"1``>G!XAX/K/X"B4PD
M8(E,)#")\,=$)#0`````B=:+5"0HBUPD4`G&B70D:(ET)$#'1"1$`````,=$
M)"0`````]](C5"0@(?.+="0X"=H#M"00`0``B=&+5"0TB?`%F7F"6@'!BT0D
M,(G+B<;!Y@6)="0XB<:+1"0H#ZS6&XM4)"R)]XMT)#B)P0G^`?/!X1XQ_P^L
MT`*)S8M,)""+5"0T"<4#C"08`0``B=Z);"0XBVPD:(E<)%")R`6AZ]EN,VPD
M.#-L)&")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)"@+;"0HBT0D,`'IB4PD
M8(E,)"")P<'A'@^LT`*)RXM4)$"+;"10"<,#E"0@`0``QT0D+`````")7"1`
MB="+5"0D!:'KV6XS7"0X,=V+7"1`B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/
MK-`;B?*)1"0P"VPD,(M$)#@!Z<'B'HML)&`/K/X"B4PD*(E,)%")\8G6BU0D
M+`G.BXPD*`$``(ET)#B!P:'KV6X!R#'S,=V)Z0'!BT0D*(G&P>8%B70D,(G&
MBT0D(`^LUAN+5"0DB?>+="0P"?X!\3'_B<Z)3"1@B<'!X1X/K-`"B<V+C"0P
M`0``"<6+1"1`B6PD,(ML)#B!P:'KV6X!R#-L)#"+5"0L,VPD4,=$)"0`````
MQT0D+`````")Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)$`+;"1`BT0D*`'I
MB4PD((E,)%")P<'A'@^LT`*)RXN,)#@!``"+5"0D"<.+1"0XB=V)7"0XBUPD
M,('!H>O9;@'(,>N+;"1@,=V+7"0XB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/
MK-`;B40D0`ML)$`!Z8ML)%")3"0HB4PD8(GQ#ZS^`L'A'HGPB<Z+C"1``0``
M"<:+1"0PB70D0('!H>O9;@'(,?,QW8GI`<&+1"0HBU0D+(G+B<;!Y@6)="0P
MB<:+1"0@#ZS6&XM4)"3'1"0D`````(GWBW0D,(G!"?X!\\'A'C'_#ZS0`HG-
MBXPD2`$``(M4)"P)Q8M$)#B)7"10B6PD,(ML)$")WH'!H>O9;@'(,VPD,#-L
M)&")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)#@+;"0XBT0D*`'IB4PD((E,
M)&")P<'A'@^LT`*)RXN,)%`!``"+5"0D"<.+1"1`B=V)7"0XBUPD,('!H>O9
M;@'(,>N+;"10,=V)Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)1"1`"VPD
M0(M<)#C'1"0L`````(M4)"P!Z8ML)&")3"10B4PD*(GQ#ZS^`L'A'HGPB<Z+
MC"18`0``"<:+1"0PB70D0('!H>O9;@'(,?,QW8GI`<&+1"0HB<N)QL'F!8ET
M)#")QHM$)"`/K-8;BU0D),=$)"0`````B?>+="0PB<$)_@'SP>$>,?\/K-`"
MB<V+C"1@`0``BU0D+`G%BT0D.(G>B6PD,(ML)$"!P:'KV6Z)7"1@`<@S;"0P
M,VPD4(GI`<&)V,'@!8E$)"")V(ML)"`/K/@;B40D.`ML)#B+1"0H`>F)3"10
MB4PD((G!P>$>#ZS0`HG+BY0D:`$```G#BT0D0,=$)"P`````B5PD.(G=BUPD
M,('"H>O9;@'0BU0D)#'KBVPD8#'=BUPD.(GI`<&+1"0@P>`%B40D*(M$)""+
M;"0H#ZS0&XM4)"R)1"1`"VPD0`'IBVPD4(E,)&")3"0HB?$/K/X"P>$>B?")
MSHN,)'`!```)QHM$)#")="1`@<&AZ]EN`<@Q\S'=B>D!P8M$)"B)RXG&P>8%
MB70D,(G&BT0D(`^LUAN+5"0DB?>+="0PB<$)_@'SP>$>,?\/K-`"B<V+C"1X
M`0``B5PD4`G%BT0D.(G>B6PD,(ML)$"!P:'KV6X!R#-L)#`S;"1@B>D!P8G8
MP>`%B40D((G8BVPD(`^L^!N+5"0LQT0D)`````")1"0X"VPD.(M$)"C'1"0L
M``````'IB4PD((E,)&")P<'A'@^LT`*)RXN4)(`!```)PXM$)$")W8E<)#B+
M7"0P@<*AZ]EN`="+5"0D,>N+;"10,=V)Z0'!BT0D(,'@!8E$)"B+1"0@BVPD
M*`^LT!N+5"0LB40D0`ML)$`!Z8ML)#B)3"0HB4PD4(GQ#ZS^`L'A'HGPB<Z+
MC"2(`0``"<:+1"0PB70D0('!H>O9;@'(,?6)[HML)&`Q]8GI`<&+1"0HB<N)
MQL'F!8ET)#")Q@^LUAN)]XMT)#`)_@'S,?^)7"1@BT0D((G>BU0D),=$)"0`
M````B<'!X1X/K-`"B<V+C"20`0``BU0D+`G%BT0D.,=$)"P`````B6PD,(ML
M)$"!P:'KV6X!R#-L)#`S;"10B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"0X
M"VPD.(M$)"@!Z8E,)"")3"10B<'!X1X/K-`"B<N+E"28`0``"<.+1"1`B=V)
M7"0XBUPD,('"H>O9;@'0BU0D)#'KBVPD8#'=B>D!P8M$)"#!X`6)1"0HBT0D
M((ML)"@/K-`;B40D0`ML)$`!Z8E,)$")3"0HB?$/K/X"P>$>B?")SHN,)*`!
M```)QHM<)#B+1"0PBVPD4(ET)#"!P:'KV6Z+5"0L`<@Q\S'=B>D!P8M$)"B)
MRXG&P>8%B70D4(G&BT0D(`^LUAN+5"0DB?>+="10B<$)_@'SP>$>,>T/K-`"
MB=^)7"1@BYPDK`$```G!BT0D.(G.BXPDJ`$``(ET)%"!P:'KV6Z#TP`QT@'(
M$=J+3"0PB40D((E4)"2+5"1`B?C'1"0D`````#'Q,<J)T0-,)"#!X`6)1"0@
MB?B+="0@#ZSH&XM4)"R)1"0X"W0D.(M$)"@!\8E,)$")3"0@B<'!X1X/K-`"
MBY0DL`$``(G.BXPDM`$```G&BT0D,(ET)#B!PJ'KV6Z#T0")RXG1,=(!R(M,
M)%`1VHE$)"B+1"0@B50D+(M4)&`Q\8M<)#C'1"0L`````#'*B=$#3"0HP>`%
MB40D*(M4)"2+1"0@BW0D*`^LT!N)VHE$)#`+="0PBT0D0`'QB?Z)3"0HB4PD
M8(GY#ZSN`L'A'C'_B<T)]8G>BYPDO`$```GN(>J);"1`(?")P8M$)%`)T8G.
MBXPDN`$``('!W+P;CX/3`#'2`<@1V@'&BT0D*!'7BU0D+(ET)#")?"0TB<8/
MK-`;P>8%B<$)\8G(BTPD,`'!B4PD:(E,)##'1"0T`````(MT)""+?"0DBT0D
M8,=$)"0`````B?'!X1X/K/X"B<L)\XMT)$")WXGZB7PD4(M\)"P)\R'RQT0D
M+``````AV(G!BT0D.`G1BY0DP`$``(G.B?.!PMR\&X\!T(M4)#0!PXM$)#")
MQ@^LT!O!Y@6)1"0@BVPD((M$)&@)]8MT)"@!ZXE<)&")7"0@B?$/K/X"BWPD
M4,'A'HG+"?.)^HGYB5PD.`G:(=DAT(M4)"2)Q8M$)$`)S8N,),@!``"!P=R\
M&X\!R(GI`<&+1"0@B<;!Y@6)="0HB<:+1"1@#ZS6&XM4)#B)]XMT)"B)TPG^
MBWPD-`'QBW0D,(E,)&B)3"0HB?'!X1X/K/X"B<T)]0GKB6PD0(N,)-`!```A
MV(G3BWPD)"'KQT0D-`````#'1"0D`````(G:B<.+1"10"=.!P=R\&X^+5"0L
M`<@!PXM$)"B)Q@^LT!O!Y@6+5"1`B40D,(ML)#"+1"1H"?6+="0@`>N)7"1@
MB5PD,(GQP>$>#ZS^`HG+"?.)WPG3(=B)^8E\)%`AT8G%BT0D.`G-BXPDV`$`
M`(M4)#2+?"0L@<'<O!N/`<B)Z0'!BT0D,(G&#ZS0&\'F!8E$)""+;"0@BT0D
M8`GUBW0D*`'IB4PD((E,)&B)\0^L_@*+?"10P>$>B<N+C"3@`0``"?.)^HE<
M)#@)VB'0B?J)Q8M$)$`AV@G5@<'<O!N/BU0D)(GN`<@!QHM$)"")\8G&P>8%
MB70D*(G&BT0D:`^LUAN+5"0XQT0D+`````")]XMT)"B)TPG^BWPD-,=$)#0`
M`````?&+="0PB4PD8(E,)"B)\<'A'@^L_@*)S8M\)"3'1"0D``````GU">N)
M;"1`(=B)TXM4)"PAZXG!BT0D4`G9B<Z+C"3H`0``B?.!P=R\&X\!R`'#BT0D
M*(G&#ZS0&\'F!8M4)$")1"0PBVPD,(M$)&`)]8MT)"`!ZXE<)#")7"1HB?'!
MX1X/K/X"B<L)\XG?"=,AV(GYB7PD4"'1B<6+1"0X"<V+C"3P`0``BU0D-('!
MW+P;CP'(B>D!P8M$)#")Q@^LT!O!Y@6)1"0@BVPD(`GU`>F)3"1@B4PD((MT
M)"B+?"0LBT0D:,=$)"P`````B?$/K/X"BWPD4,'A'HG+BXPD^`$```GSB?J)
M7"0X"=HAT(GZB<6+1"1`(=H)U8'!W+P;CXM4)"2)[@'(`<:+1"0@B?&)QL'F
M!8ET)"B)QHM$)&`/K-8;BU0D.(GWBW0D*(G3"?Z+?"0TQT0D-``````!\8MT
M)#")3"1HB4PD*(GQP>$>#ZS^`HG-BWPD)`GU">N);"1`(=B)TXM4)"PAZXG!
MBT0D4`G9B<Z+C"0``@``B?.!P=R\&X\!R`'#BT0D*(G&#ZS0&\'F!8M4)$")
M1"0PBVPD,(M$)&@)]8MT)"`!ZXE<)&")7"0PB?'!X1X/K/X"B<L)\XG?"=,A
MV(GYB7PD4"'1B<6+1"0X"<V+C"0(`@``BU0D-(M\)"S'1"0D`````,=$)"P`
M````@<'<O!N/`<B)Z0'!BT0D,(G&#ZS0&\'F!8E$)""+;"0@BT0D8`GUBW0D
M*`'IB4PD:(E,)"")\0^L_@*+?"10P>$>B<N+C"00`@``"?.)^HE<)#@)VB'0
MB?J)Q8M$)$`AV@G5@<'<O!N/BU0D)(GN`<@!QHM$)"")\8G&P>8%B70D*(G&
MBT0D:`^LUAN+5"0XB?>+="0HB=,)_HM\)#0!\8MT)#")3"0HB4PD8(GQP>$>
M#ZS^`HG-"?4)ZXEL)$`AV(G3BU0D+"'KB<&+1"10"=F)SHN,)!@"``")\X'!
MW+P;CP'(`<.+1"0HB<8/K-`;P>8%B40D,(ML)#"+?"0DBU0D0(M$)&#'1"0T
M``````GUBW0D(,=$)"0``````>N)7"1HB5PD,(GQP>$>#ZS^`HG+"?.)WPG3
M(=B)^8E\)%`AT8G%BT0D.`G-BXPD(`(``(M4)#2+?"0LQT0D+`````"!P=R\
M&X\!R(GI`<&+1"0PB<8/K-`;P>8%B40D((ML)""+1"1H"?6+="0H`>F)3"0@
MB4PD8(GQ#ZS^`HM\)%#!X1Z)RXN,)"@"```)\XGZB5PD.`G:(=")^HG%BT0D
M0"':"=6!P=R\&X^+5"0DB>X!R`'&BT0D((GQB<;!Y@6)="0HB<8/K-8;B?>+
M="0H"?X!\8E,)&B)3"0HBW0D,(M\)#2+5"0XBT0D8,=$)#0`````B?'!X1Z)
MTP^L_@*)S8M\)"3'1"0D``````GU">N);"1`(=B)TXM4)"PAZXG!BT0D4`G9
MB<Z+C"0P`@``B?.!P=R\&X\!R`'#BT0D*(G&#ZS0&\'F!8M4)$")1"0PBVPD
M,(M$)&@)]8MT)"`!ZXE<)&")7"0PB?'!X1X/K/X"B<L)\XG?"=,AV(GYB7PD
M4"'1B<6+1"0X"<V+C"0X`@``BU0D-(M\)"R!P=R\&X\!R(GI`<&+1"0PB<8/
MK-`;P>8%B40D((ML)""+1"1@"?6+="0H`>F)3"1HB4PD((GQ#ZS^`HM\)%#!
MX1Z)RPGSB?J)7"0XBXPD0`(```G:QT0D+``````AT(GZB<6+1"1`(=H)U8'!
MW+P;CXM4)"2)[@'(`<:+1"0@B?&)QL'F!8ET)"B)QHM$)&@/K-8;BU0D.(GW
MBW0D*(G3"?Z+?"0TQT0D-``````!\8MT)#")3"1@B4PD*(GQP>$>#ZS^`HG-
M,?\)]0GKB6PD0"'8B=,AZXG!BT0D4`G9BYPD3`(``(G.BXPD2`(``('!W+P;
MCX/3`#'2`<@1VHGSB?X!PXM$)"B+?"0D$=:+5"0LB=F)\XG&#ZS0&\'F!3'2
MB40D,(ML)#"+1"1@"?6)WHG+`>L1UHE<)&B)7"0PB70D;(MT)"")\<'A'@^L
M_@*)RXM\)$`)\XG>B=F)7"10"?XA^2'PB<6+1"0X"<V+C"10`@``@<'<O!N/
M`<B)Z0'!BT0D,(M4)#2+?"0LQT0D)`````")Q@^LT!O!Y@6+E"18`@``B40D
M((ML)"`)]8MT)"@!Z8ML)%")3"1@B4PD((GQ#ZS^`L'A'HGPB<X)QHM$)$"!
MPM;!8LJ)="0X`=`Q]8M4)"2)[HML)&@Q]8GI`<&+1"0@B<N)QL'F!8ET)"B)
MQHM$)#`/K-8;BU0D-(GWBW0D*(G!"?X!\\'A'C'_#ZS0`HG-BXPD8`(``(E<
M)$`)Q8M$)%")WHEL)#"+;"0X@<'6P6+*`<@S;"0P,VPD8(GI`<&)V,'@!8E$
M)"B)V(ML)"@/K/@;B40D4`ML)%`!Z8E,)%")3"0HBT0D((M4)"3'1"0L````
M`,=$)"0`````B<'!X1X/K-`"B<N+C"1H`@``BU0D+`G#BT0D.(G=B5PD.(M<
M)#"!P=;!8LH!R#'KBVPD0#'=BUPD.(GI`<&+1"0HP>`%B40D((M$)"B+;"0@
M#ZS0&XM4)"2)1"1`"VPD0`'IBVPD4(E,)"")3"1@B?$/K/X"P>$>B?")SHN,
M)'`"```)QHM$)#")="1`@<'6P6+*`<@Q\S'=B>D!P8M$)"")RXG&P>8%B70D
M,(G&BT0D*`^LUAN+5"0LB?>+="0PB<$)_@'SP>$>,?\/K-`"B<V+C"1X`@``
MB5PD4`G%B=Z);"0PBT0D.('!UL%BRHML)$"+5"0DQT0D+`````#'1"0D````
M``'(,VPD,#-L)&")Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#@+;"0XBT0D
M(`'IB4PD*(E,)&")P<'A'@^LT`*)RXN4)(`"```)PXM$)$")W8E<)#B+7"0P
M@<+6P6+*`="+5"0L,>N+;"10,=V)Z0'!BT0D*,'@!8E$)""+1"0HBVPD(`^L
MT!N)1"1`"VPD0`'IBVPD.(E,)$")3"0@B?$/K/X"P>$>B?")SHN,)(@"```)
MQHM$)#")="0P@<'6P6+*`<@Q]8GNBVPD8(M4)"0Q]8GI`<&+1"0@B<N)QL'F
M!8ET)%")QHM$)"@/K-8;BU0D+,=$)"P`````B?>+="10B<$)_@'SP>$>,?\/
MK-`"B<V+C"20`@``B=X)Q8E<)%"+1"0XBUPD,(EL)#B!P=;!8LJ+5"0D`<@Q
MZXML)$`QW8GI`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D0`ML)$"+1"0@`>F)
M3"0HB4PD8(G!P>$>#ZS0`HG-BY0DF`(```G%BT0D,(EL)$"!PM;!8LH!T#-L
M)#B+5"0L,VPD4(GI`<&+1"0HP>`%B40D((M$)"@/K-`;B40D,(ML)"`+;"0P
MBUPD0,=$)"0`````BU0D)`'IBVPD8(E,)%")3"0@B?$/K/X"P>$>B?")SHN,
M)*`"```)QHM$)#B)="0X@<'6P6+*`<@Q\S'=B>D!P8M$)"")RXG&P>8%B70D
M,(G&BT0D*`^LUAN+5"0LQT0D+`````")]XMT)#")P0G^`?/!X1XQ_P^LT`*)
MS8N,)*@"``"+5"0D"<6+1"1`B=Z);"0PBVPD.('!UL%BRHE<)&`!R#-L)#`S
M;"10B>D!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)%")
M3"0HB<'!X1X/K-`"B<N+E"2P`@``QT0D)``````)PXM$)#B)W8E<)#B+7"0P
M@<+6P6+*`="+5"0L,>N+;"1@,=V)Z0'!BT0D*,'@!8E$)""+1"0HBVPD(`^L
MT!N+5"0DB40D0`ML)$`!Z8ML)#B)3"0@B4PD8(GQ#ZS^`L'A'HGPB<Z+C"2X
M`@``"<:+1"0PB70D0('!UL%BR@'(,?6)[HML)%`Q]8GI`<&+1"0@B<N)QL'F
M!8ET)#")QHM$)"@/K-8;BU0D+(GWBW0D,(G!"?X!\\'A'C'_#ZS0`HG-BXPD
MP`(``(E<)%`)Q8M$)#B)WHEL)#"+;"1`@<'6P6+*`<@S;"0P,VPD8(M4)"3'
M1"0L`````,=$)"0`````B>D!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"0X"VPD
M.(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<N+E"3(`@``"<.+1"1`B=V)7"0X
MBUPD,('"UL%BR@'0BU0D+#'KBVPD4#'=BYPDU`(``(GI`<&+1"0HP>`%B40D
M((M$)"B+;"0@#ZS0&XE$)$`+;"1``>F+;"0XB4PD((E,)%")\0^L_@+!X1Z)
M\(G.BXPDT`(```G&BT0D,(ET)$"!P=;!8LJ#TP`QT@'($=HQ]3';B>Z+;"1@
M,?6)Z0'!BT0D(!'3BU0D)(G&P>8%B=>)="0PB<8/I,<%#ZS6&XE\)#0QTHGW
MBW0D,`G^B?")WHG+`<.+1"0H$=:+5"0LB=F)3"1@B70D9(G.B<$Q_\=$)"P`
M````#ZS0`L'A'HM4)"2)S8N,)-@"```)Q8M$)#B);"0PBVPD0('!UL%BR@'(
M,VPD,#-L)%")Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#@+;"0XBT0D(`'I
MB4PD*(E,)%")P<'A'@^LT`*)RXN4).`"```)PXM$)$")W8E<)#B+7"0P@<+6
MP6+*`="+5"0L,>N+;"1@,=V)Z0'!BT0D*,'@!8E$)""+1"0H#ZS0&XE$)$"+
M;"0@"VPD0,=$)"0`````BU0D)`'IBVPD.(E,)"")3"1`B?$/K/X"P>$>B=>)
M\(G.BXPDZ`(```G&BT0D,(ET)#"!P=;!8LH!R#'UB>Z+;"10,?6)Z0'!BT0D
M((G&P>8%B70D4(G&#Z3'!0^LUAN)?"14BU0D+(GWBW0D4`G^B?`!R#'_B<:+
M1"0HB<'!X1X/K-`"B<V+5"0@BTPD)`G%BT0D.(EL)%`/I-$>P>(>B50D*(E,
M)"R+5"0@BTPD)`^LR@+!Z0*)3"0DBXPD\`(``(E4)"")^H'!UL%BR@'(BTPD
M,#'IBVPD0#'-B>D!P8GPP>`%B40D.(GP#Z3R!0^L^!N)5"0\B?J)1"1`BVPD
M.,'J&PML)$")5"1$B>B+;"0H`<B)P0-,)!"+1"1,B</'0`0`````B0B+1"08
MQT,,`````,=#%`````#'0QP`````QT,D``````'P"VPD((E#"(GH`P0DB4,0
MBT0D4`-$)`B)0QB+1"0P`T0D6(E#((N$)/P"``!E,P44````=0N!Q`P#``!;
M7E]=P^B[(0``C70F`(V\)P````!55U93Z"?9__^!PX.1``"#[!R%P'1OBXL4
M`0``BPF%R8E,)`AT7P^V"(3)=&.`^3UT7HG&@\8!#[8.A,ET!8#Y/77Q*<:+
M3"0(BRF%[70VB50D#(E$)`2)SXVT)@````"#[`16_W0D#%7H`M;__X/$$(7`
M=0>`?#4`/70<@\<$BR^%[77;@\0<,<!;7E]=PY`Q]NNQC70F`(GZ*U0D"(M$
M)`S!^@*)$(/$'(U$-0%;7E]=PXVV`````(V\)P````!75HG&4^B2V?__@<+"
MD```@^P0B[H4`0``C5PD"&6A%````(E$)`PQP(G:B?#H#O___X7`=#N-=@"-
MO"<`````BU0D"(L'C020BU`$A=*)$'37C;8`````@\`$BU`$A=*)$'7TB=J)
M\.C3_O__A<!USXM$)`QE,P44````=0>#Q!!;7E_#Z&8@``"-M@````!55XG%
M5E.)UNC3U___@<,OD```@^PX9:$4````B40D*#'`,<"`.CT/E,`!QE;H1M3_
M_X/$$(D$)(GHC50D&.AM_O__A<`/A`T!``"#[`R)QU#H(M3__X/$$#D$)`^&
MW@```(M$)!B-#(4`````BX,4`0``B40D!`^V10"$P`^$E`$``#P]#X2,`0``
MB>CK!I"`^CUT"H/``0^V$(32=?$IZ(M4)`2#[`R+.@'/BTPD#(U$"`)0Z(;3
M__^#Q!"%P(D'#X1C`0``BU0D!(U-`8L"BU0D&(L4D`^V10`\/8@"=".$P'4/
MZQV)]HV\)P`````\/700@\$!#[9!_X/"`83`B`)U[,8"/3'`C;0F``````^V
M#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/A0(!``"#Q"Q;7E]=PXVV````
M`(/&`0^V1O^#QP&$P(A'_W7OZ\R0C70F`(N#%`$``(L0B40D!(LZA?\/A+``
M```QP.L(C;8`````B?B->`&+#+J%R77TC02%#````(N+=!$``(7)=#.#[`A0
M4NB9TO__BTPD%(/$$(7`B0%T?HT,O0````#'1+@$`````(E\)!CIL_[__XUT
M)@")5"0(@^P,QX-T$0```0```%#H8=+__X/$$(7`=$2-#+T`````@^P$48M4
M)!")3"044HE$)!10Z(S1__^+3"04BT0D&(/$$(D!BTPD#.N<,<#I@_[__[@(
M````,?_I8?___[C_____Z>W^___H)QX``(VT)@````!55U93B<;HE=7__X'#
M\8T``('LC````&6A%````(E$)'PQP(7V=`6`/@!U)(M$)'QE,P44````#X4T
M`0``@<2,````6UY?7<.0C;0F`````(/L#%;HM]+__X/$$(7`B<=TRHV#5)#_
M_XE$)`B-1"0<B40D#(UT)@"#[`Q7Z$_2__^#Q!"%P(G%#X2Z````@'T3+@^$
MB````(/L#%;HE]'__XU5$XE$)!2)%"2)5"00Z(31__^+3"04C40!`HD$).@\
MT?__B<586HM4)`A25O]T)!AJ_VH!5>@\TO__@\0<_W0D$%5J`^C]T?__@\00
M@_C_=!"+1"0L)0#P```]`$```'1E@^P,5>B,T/__@\00@^P,5>A`T/__@\00
MZ5C___\/MD44A,`/A$S___\\+@^%9/___X!]%0`/A#K____I5?___Y"-="8`
M@^P,5^BWT?__B30DZ!?0__^#Q!#IR_[__XVT)@````")Z.B1_O__ZY[HJAP`
M`(UV`(V\)P````!75HG'4^@6U/__@<-RC```@^P,B[-,````_S;H4-'__X/$
M#`4X`0``4%=J`^A'T?__@\00A<!T"%LQP%Y?PV:0@^P,_S;H)M'__XN`2`$`
M`(/$$"4`\```/0!```!T'X/L#/\VZ`?1__^+@$@!``"#Q!`E`/```#T`H```
M=;J#[`AJ`E?HG]#__X/$$(7`#Y3`6P^VP%Y?PY"-M"8`````55>)QU93Z'73
M__^!P]&+``"![#`0``!EH10```")A"0@$```,<")5"00:/\/``"-@UJ0__^-
M="0D5E#H4,___X/$$(7`?F&-:/^`?"P<`'1/B<6#[`15:B]6Z/G/__^#Q!"%
MP'1"BX-,````@^P,_S#H6M#__U565U#H(=#__X/$((N$)!P0``!E,P44````
M=3F!Q"P0``!;7E]=PXUV`(7M=:^-="8`BX-,````@^P,_S#H&-#__X/$#/]T
M)!!74.C2SO__@\00Z[?H,!L``%/HJM+__X'#!HL``(/L%(N#3````/\PZ.3/
M__^-DUR2__]2C9-ID/___[,T````4E#H,L___X/$*%O#D(UT)@!64^AITO__
M@</%B@``@^P0B[-,````_S;HH\___XD$).B;____6/\VZ)//__]:C9,IDO__
M66H`4E*-D_2*__]2C9.%D/__4E#H(\___X/$)%M>PXVV`````(V\)P````!5
M5U93Z`?2__^!PV.*``"![!P@``!EH10```")A"0,(```,<#H+\[__XV399#_
M_X/L"%)0C8.:D/__4&@!$```:@&-="0F5N@\S___@\0@A<!X;8/L!&@`$```
MC;PD$Q```%=6Z+?-__^#Q!"%P(G%>$Z-0`&#[`Q0Z/+-__^#Q!"%P(G&=#F#
M[`155U#H/LW__\8$+@"#Q!")\(N,)`P@``!E,PT4````=1F!Q!P@``!;7E]=
MPXUV`(V\)P`````QP.O7Z,<9``"-M"8`````Z2O___^-="8`C;PG`````%57
M5E/H)]'__X'#@XD``('L/!```&6A%````(F$)"P0```QP(NT)%`0``"-5"0H
MC8.HD/__B[PD5!```.B_]___@^P(B<5J+U;H:LW__X/$$(7`="Z-@[&0__^)
M\NCN^/__B?"+E"0L$```93,5%`````^%<@$``('$/!```%M>7UW#@^P,5N@\
MS?__6EF)1"0@C8.^D/__B40D)%!7Z)W-__^#Q!"%P(G'=*F-DZ:0__^)="04
MBW0D'(E4)!"+DTP```")5"0,D(VT)@````"`/P`/1'PD$(7M=!6#[`A75>CB
MR___@\00A<`/A*@```"#[`Q7Z,[,__^#Q!"`?`?_+W42C70F`(/H`8!\!_\O
MQ@0'`'3RBTPD&(U$"`$]_P\```^/B````(V#P)#__X/L!/]T)!A0C8/DD?__
M5U!H`!```&H!C7PD2%?H6,W__X/$%(M$)!C_,.@BS?__@\0,!3@!``!05VH#
MZ`G-__^#Q!"%P'4C@^P,BT0D&/\PZ/S,__^+@$@!``"#Q!`E`/```#T`@```
M="&#[`A6:@#HG,S__X/$$(7`B<</A1____^+="04Z9O^__^#[`AJ`5?H<\S_
M_X/$$(7`=<V-@[&0__^)^NAW]___@^P,5^@6S/__@\00Z7K^___HP1<``)"+
M1"0$#[8(A,ET%8U0`6:0@/DO#[8*#T3"@\(!A,EU\//#C;0F`````(V\)P``
M``!64^@)S___@<-EAP``@^P4BW0D((7V=#@/MA:$TG0QB%0D#X/L#%;H?,O_
M_XU$!O^#Q!`/ME0D#SG&<@OK/F:0@^@!.<9T.8`X+W3TZR=FD(/L#&H"Z!;+
M__^#Q!"%P'1_NBX```!FB1"#Q!1;7L.0@#@O=#"#Z`$YQG+T.<9U)8#Z+W3+
MC8/`D/__@^P,4.A$R___@\00Z]"-M"8`````@#@O=0>#Z`$YQG+T*?"-4`*!
M^@`0``!W)X/``6@`$```4%:-LW0!``!6Z#'+__^#Q!")\(/$%%M>PXVV````
M`(/$%#'`6U[#D(VT)@````!75E/H&,[__X'#=(8``(/L,&6A%````(E$)"PQ
MP(N#.)+__XUT)`2)1"0*BX,\DO__B40D#HN#0)+__XE$)!*+@T22__^)1"06
MBX-(DO__B40D&HN#3)+__XE$)!Z+@U"2__^)1"0BBX-4DO__B40D)@^W@UB2
M__]FB40D*HV#PI#__^@H]?__C8/+D/__Z!WU__^-@].0___H$O7__XV#W)#_
M_^@']?__C8/CD/__Z/ST__^-@_.0___H\?3__XV#J)#__^CF]/__C8/_D/__
MZ-OT__^-@PF1___HT/3__XV#$Y'__^C%]/__C8.QD/__Z+KT__^-@QV1___H
MK_3__XV#)I'__^BD]/__C8,QD?__B?+HU_/__X7`=`V)PHV#"9'__^@6]?__
MC8-"D?__B?+HN?/__X7`=`V)PHV#5)'__^CX]/__C8-?D?__B?+HF_/__X7`
M=#>)PHV#J)#__^C:]/__C9.+D?__C8/CD/__Z,GT__^+1"0L93,%%````'50
M@\0P6UY?PY"-="8`C8-OD?__B?+H4_/__X7`=`^)PHV#_Y#__^B2]/__Z[:-
M="0;C;N`D?__N0H```#SIG6CC50D)8V#_Y#__^AN]/__ZY+HQQ0``(VT)@``
M``!3Z#K,__^!PY:$``"#[!AEH10```")1"0,,<"+@SP!``"#^/]T&HM,)`QE
M,PT4````=4&#Q!A;PY"-M"8`````C50D"(V#_Y#__^C!\O__A<!T'0^V$(#Z
M,`^5P(32#Y7"#[;2(=")@SP!``#KN&:0,<#K\NA'%```C;0F`````%/HNLO_
M_X'#%H0``(/L".B<Q___@^P,4.A+Q___@\00A<!T#(L`@\0(6\.0C70F`#'`
MZ_*-M@````"-OP````!55U93Z'?+__^!P].#``"#[%R+1"1PC;N7D?__C;.-
MD?__QT0D2`````"-;"0PB7PD,(ET)#2)1"0(9:$4````B40D3#'`C8.:D?__
MB40D.(V#D)'__XE$)#R-@Y61__^)1"1`C8.GD?__B40D1(U$)"R)1"0,C8.^
MD/__B40D%(V#Y)'__XE$)!CK*(UT)@"#[`C_="004(E$)"#H;\;__X/$$(7`
M=$B#Q02%]G0KB?>+=02+5"0,B?CHD?'__X7`=`6`.`!UR(M4)`B)^(/%!.C*
M\O__A?9UU8M$)$QE,P44````=6Z#Q%Q;7E]=PY"#[`S_="04Z!S'__^+3"0@
MB40D+(D,)(E,)"#H",?__XM4)"R-1`("B00DZ,#&__^#Q`R+3"044?]T)!S_
M="04_W0D*&K_:@%0B40D,.BVQ___@\0@BU0D$(GXZ%#R___I4____^BF$@``
MC;8`````55=64^C>$0``@<%S@@``@>P\@0``BX0D4($``(UL)#R-F;*1__^)
M3"0(QT0D2`````")ZL=$)&P`````B5PD3(E$)!#'1"14`````&6A%````(F$
M)"R!```QP(V!OI'__XE$)$"-@::0__^)1"1$C8%4D?__B40D&(E$)%B-@4V1
M__^)1"1<C8'#D?__B40D8(V!:I'__XE$)&2-@<N1__^)1"1HC8'/D?__B40D
M4(V!J)#__^@V\/__A<!T"8`X``^%R00``.B4_?__A<")Q@^$WP0``(/L#%:+
M7"08Z-7%__^-1``!@\00@^P,4(M<)!CHB<7__XE$)!R#Q!"`/@")QXM$)`B-
M@-B1__]T.8EL)!R)_8G'B?:-O"<`````#[8&@^P,@\8!4%=J_VH!58M<)"B#
MQ0+H7,;__X/$((`^`'7<BVPD'(U<)%B+1"08ZP^-M@````"#PP2+`X7`=#>)
MZNB([___A<")QG3J@#@`=.7HB/3__X7`=-R#[`Q6BUPD&.A?Q?__@\00A<")
MQW58C;8`````BUPD0(7;=$B`.P"^`0```'46ZSR-="8`BURT0(7;=#"#Q@&`
M.P!T*(G8Z#GT__^%P'3E@^P,4XM<)!CH$,7__X/$$(7`=-&)Q^L'D(UT)@`Q
M_X/L#%>+7"08Z,'$__^#Q!"+3"0,BQF#P02-D__^_O[WTR':@>*`@("`=.F)
MT\'K$/?"@(````]$TXU9`@]$RXG3`-.#V0,K3"0,@^P,C;0!!`0``%:+7"08
MZ#C$____="0<BU0D'(G!C8+=D?__B=-0C8+`D/__B40D,%"-@N*1__]74&K_
M:@&)3"0X4>@<Q?__@\0H:,`!``#_="08Z%/$__^#Q!"#^/\/A(\```"#[`R+
M1"04B[A,````B</_-XE$)!CHO<3__X/$#`4X`0``4/]T)!1J`XM<)!CHK<3_
M_X/$$(7`#X2:````@^P,_W0D&(M$)"#_,(M<)!R-@Z22__]0BX,@````:@'_
M,.A;Q/__@\0@,<"+E"0L@0``93,5%`````^%3@H``('$/($``%M>7UW#C;0F
M`````.C#P___BP"#^!$/A&'___^#[`A0_W0D&(M$)"#_,(M<)!R-@VB2__]0
MBX,@````:@'_,.CXP___@\0@,<#KFXGVC;PG`````(/L#/\WBUPD&.CRP___
MBX!(`0``@\00)0#P```]`$````^%/____X/L#/\WBUPD&.C+P___BUPD&(N`
M4`$``(E$)"SH6,+__X/$$#E$)!P/A1'___^#[`S_-XM<)!CHG</__XN`2`$`
M`(/$$"7_`0``/<`!```/A>K^__^#[`Q6BWPD&(G[Z(7"__^)1"0LC8>0D?__
MB>KHY.S__X/$$(7`#X3Y`0``@^P,4(M<)!CHQ,+__UI94(M$)!S_,.B^]/__
M@\00A<")Q0^$T0$``(/L#%6+?"08B?OH:L+__X/$$(/X`WXJC70%_(V_ZY'_
M_[D%````\Z9U%X/X!`^$C@<``(!\!?LO#X2#!P``C78`Z%OY__^%P'4>@^P(
M:@!5BUPD&.@PPO__B40D,(/$$(7`#X5T`0``BVPD"#'VC96+D?__C;TIDO__
MC87_D/__B>OH>NW__^B=P?__5U"-A022____="0@_W0D&(VM$I+__U!J_VH!
M_W0D..BIPO__@\0@B7PD$(M\)!SK08UT)@"+7"0(Z.?!__^#.!%U28M<)`B#
MQ@'H3L'__X/L#/]T)!Q64/]T)##_="0H56K_:@%7BUPD..A>PO__@\0P@^P(
M:,`!``!7BUPD&.B1P?__@\00@_C_=*F#[`S_="08BW0D&(GSZ&_`__^+?"0L
MC8:HD/__B?KHQNS__XD\).@>^?__@\00B?CI=OW__XUT)@"#[`Q0B40D'.@#
M^?__BT0D'(M<)!B)!"3H.\'__X/$$.E-_?__OP$```")V.L-9I"+1+Q,@\<!
MA<!T*XGJZ![K__^%P'3J@#@`=.6#[`Q0BUPD&.@`P?__@\00A<!TT8G&Z>#Z
M__^+5"0(N`T```"-LK>1___IX/K__XVV`````(M$)!"+*.DD_O__:@)J_VKN
MBW0D+%:+?"08B?OH+\#__X/$#&H&C80D-`$``(E$)!A05NAXO___@\00@+PD
M+`$```!U#H"\)"T!``!##X1E!@``:@!J`&H`_W0D+(M<)!CHZK___\>$)(``
M```!(T5GQX0DA`````````#'A"2(````B:O-[\>$)(P`````````QX0DD```
M`/[<NIC'A"24`````````,>$))@```!V5#(0QX0DG`````````#'A"2@````
M\.'2P\>$)*0`````````QX0DJ`````````#'A"2L`````````,>$)+``````
M````QX0DM`````````#'A"3X`````````(/$$(U$)'")1"0LC80DJ````(E$
M)"2-M"8`````@^P$:`"```#_="08_W0D+(M<)!CH;[[__X/$$(7`B<8/COL!
M``"+C"28````BYPDG````(GPB?7!X`.)]\']'P'(@_L`#X>]`0``.<$/A[4!
M``"+C"2@````BYPDI````(F$))@```")^(GJ#ZSH'<'J'<>$))P`````````
M`<B)A"2@````BX0DZ````!':B90DI````(7`#X19`0``O4`````IQ3GN#T[N
M`T0D)(/L!%7_="084(M<)!CHY[W__XN$)/@````!Z(F$)/@```"#Q!"#^$`/
MA2/___^+1"0L*>X#;"00Z"S#__^-="8`@_X_#XX:!```@^Y`B?>)="0HB>[!
M[P:-7P'!XP8!ZXML)"R0C70F`(L&@\9`B80DJ````(M&Q(F$)*P```"+1LB)
MA"2P````BT;,B80DM````(M&T(F$)+@```"+1M2)A"2\````BT;8B80DP```
M`(M&W(F$),0```"+1N")A"3(````BT;DB80DS````(M&Z(F$)-````"+1NR)
MA"34````BT;PB80DV````(M&](F$)-P```"+1OB)A"3@````BT;\B80DY```
M`(GHZ%?"__\Y\P^%3____XMT)"C!YP8I_FI$5E/_="0PBUPD&.AUO?__B;0D
M^````(/$$.D._O__C;8`````BVPD$.GO_O__C;0F`````(N,)*````"+G"2D
M````@\$!@],`Z4#^__^#[`S_="0LBUPD&.@7OO__BX0DL````(N<)*@```"+
MM"2L````BY0DM````(E$)"")V`^L\`.)5"0D@^`_C5`!QH0$N````("#Q!"#
M^C@/CZ4"``"X.````"G0`U0D)(/X!`^#RP(``(7`=`NH`L8"``^%B`,``(M\
M)!"+;"04B)PDYP```(GX#ZSH&(B$).````")^`^LZ!"(A"3A````B?@/K.@(
MB(0DX@```(GXB(0DXP```(G8#ZSP&(B$).0```")V`^L\!"(A"3E````B=@/
MK/`(B(0DY@```(M$)"SH$<'__XMT)'"+?"1TC90D`P$``(E4)"")U8M4)`B)
M\0^L^1B-DMB1__^(C"3O````#[;!B?$/K/D0B(PD\````(GQ#ZSY"(M\)'R(
MC"3Q````B?&+="1XB(PD\@```(GQ#ZSY&(B,)/,```")\0^L^1"(C"3T````
MB?$/K/D(B[PDA````(B,)/4```")\8NT)(````"(C"3V````B?$/K/D8B(PD
M]P```(GQ#ZSY$(B,)/@```")\0^L^0B+O"2,````B(PD^0```(GQB[0DB```
M`(B,)/H```")\0^L^1B(C"3[````B?$/K/D0B(PD_````(GQ#ZSY"(N\))0`
M``"(C"3]````B?&+M"20````B(PD_@```(GQ#ZSY&(B,)/\```")\0^L^1"(
MC"0``0``B?$/K/D(C;PD*P$``(B,)`$!``")\8VT)/````"(C"0"`0``B7PD
M$(GWB=;I"````&:0#[8'@\<!@^P,4%9J_VH!58M<)"B#Q0+HW+O__X/$(#EL
M)!!UVXM<)`C&A"0K`0```(V#*9+__U"-@_61____="0D_W0D(/]T)!A0:O]J
M`?]T)#CHH+O__X/$(.E7^?__BT0D$(M0!(72#X1Q^/__@^P,4HM\)!B)5"0@
MB?OHEKK__X/$$(/X`P^&4OC__XM4)!"-O_"1__^Y!0```(UT`OSSI@]$ZNDU
M^/__B>OIN/S__XM\)"2X0````"G0C0P7B<)T#3'`Q@0!`(/``3G0<O6+1"0L
MZ-:^__^+?"0DN0X````QP/.KZ43]__^-2@3'`@````#'1`+\`````(/A_"G*
M`<*#XOR#^@0/@B#]__^#XOPQP,<$`0````"#P`0YT'+RZ0C]__^`O"0N`0``
M00^%C?G__X"\)"\!``!##X5_^?__@+PD,`$``$@/A7'Y__^`O"0Q`0``10^%
M8_G__VH":O]JQHML)"Q5BWPD&(G[Z$JY__^#Q`QJ*8MT)!A65>B:N/__C8<I
MDO__4(V']9'__U;_="0P_W0D*%!J_VH!_W0D2.A.NO__@\0PZ07X__^-M@``
M```Q[6:);`+^Z6S\___H-P4``(VT)@````!55U93Z*>\__^!PP-U``"#[#B+
MJTP```!EH10```")1"0H,<#_=0#HU+G__\9`90&-1"0HB40D'(G"C8/CD/__
MZ#OC__^#Q!"%P'0)@#@Q#X1;`@``Z#;N__^#[`S_=0#HF[G__XV3(Y+__VH+
M:@%24.BBN/__@\0@A<`/A,````"+0`R#NWP1```!BT`8B40D!`^.J0```#'_
MO@$```#K,XVT)@````"+0@R#[`A0BX-X$0``_S2PZ(NW__^#Q!"%P'5LBX-\
M$0``@\8!@\<!.?!^8H/L#/]U`.@AN?__:@!7_W0D'%#HW+C__X/$((7`=#V+
M$(M"""4`!"``/0`$``!TI(E4)`B#[`S_=0#H[;C__VH":@"+5"0@4E#HKK?_
M_X/$(.N$B?:-O"<`````BX-\$0``C5#_.?H/A"\!``"#[`S_=0#HM+C__XV3
M*)+__VH#:@%24.B[M___@\0@A<")QG0SBT`,@^P,BSC_=0#HBKC__XV3*I+_
M_X/$#%)74.A!M___BT8,@\00BS#V1@I`#X47`@``@^P,_W4`Z%RX__^-DR^1
M__]J`VH!4E#H8[?__X/$((7`B<9T/XM4)`R-@[&0___HL^'__X7`B<</A&D!
M``"+1@R#[`R+$(E4)!#_=0#H%;C__X/$#%>+5"0,4E#HSK;__X/$$(/L#/]U
M`.CXM___BU0D',9`90"-@ZB0___H9>'__X/$$(7`B<>)@X`1```/A)(```"#
M[`AHP`$``%#H-+?__XU0`8/$$(/Z`78)@_@1#X60`0``BT0D'&4S!10````/
MA7H!``"#Q"Q;7E]=PXVT)@````"#^`$/CLC^__^+?"0$O@$```"-M@````"#
M[`S_=0"#Q@'H:K?__UI95U#HV;7__X/$$#FS?!$``'_>Z9+^__^0@'@!``^$
MH/W__^F6_?__D(/L#/^S>!$``.C"[___@\00A<")@X`1```/A.T```"+1@R+
MDW@1``"+.(M'""4`!"``/0`$```/A8T```"+1PR#[`A24.BNM?__B<>+1@R#
MQ!"+,(M&""4`!"``/0`$``!U3(M&#%=0BX-X$0``_S"-@QR3__]0Z"2V__^-
M="8`BX-X$0``@^P,BQ"+1@R)5"00BSC_=0#HI+;__XM4)!2)^.C)Y?__@\00
MZ8[^__^#[`S_=0#HAK;__VH":@!64.A+M?__@\0@ZYR)5"0$@^P,_W4`Z&>V
M__]J`FH`5U#H++7__X/$((M4)`3I4/___X/L#/]U`.A%MO__6EE64.C4M?__
M@\00Z<W]__^-@_B2__^#[`Q0Z(6U___H4`$``%"+@W@1``!7_S"-@T23__]0
MZ&JU__^-=@"-O"<`````5U93BW0D$.BDN/__@<,`<0``@^P,5NB%Z?__#[80
M@\00B<>$TG09C4`!C;8`````@/HO#[80#T3X@\`!A-)U\.@K[/__A?9T((7`
M=!R`/@!T%XV#W9'__X/L"%!7Z-ZS__^#Q!`Y^'0$6UY?PUN)\%Y?Z9GB__^+
M#"3#9I!FD)!3Z"JX__^!PX9P``"#[`B-@S@!``"%P'0?BP!0_W0D'/]T)!S_
M="0<Z#NT__^#Q!A;PXVV`````#'`Z]]FD&:055=64^CGM___@<-#<```@^P,
MBVPD((VS"/___^@CL___C8,$____*<;!_@*%]G0E,?^-M@````"#[`3_="0L
M_W0D+%7_E+L$____@\<!@\00.?=UXX/$#%M>7UW#C78`\\-FD&:09I!FD&:0
M9I!FD%/H>K?__X'#UF\``(/L".A4L___4X/L".ACM___@<._;P``@\0(6\,#
M`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N
M`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!0
M15),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!
M4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=6
M7S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U0
M1$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!
M3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%
M4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`
M)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0````!?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P
M,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@
M)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X
M:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@
M>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6
M>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS
M92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!
M4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM
M>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E
M=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S
M+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?
M1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F
M9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T
M(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S
M970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D
M(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@
M<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR
M96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M
M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\
M?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@
M=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?
M1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L
M("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D
M8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I
M<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY
M("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F
M=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I
M;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R
M:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N
M86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O
M?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE
M(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*
M8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES
M("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\[
M"B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y
M?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@
M7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I
M('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69]
M.PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G
M5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM
M>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%
M35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`
M861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0[
M"GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H
M<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H
M+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N
M="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M
M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B
M)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M
M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.
M?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#([
M"G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H
M)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@
M86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H
M*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY
M("@D9F@L("1F:6QE;F%M92D["B1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R
M8R1E>'0B.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA
M;64@:68@+64@)&9I;&5N86UE.PIP=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M"GT*96QS92!["G)E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F
M:6QE;F%M92D["GT*;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PIR971U<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*``$;`SOH````'````"!R__\$`0``('3__[0-``#0=___*`$``'"=
M__]L`0``,)[__]`!``#`GO__"`(```"A__^(`@``@*+__T`#```@H___L`,`
M`/"C__],!```,*3__WP$``"0I/__R`0``&"E__]<!0``<*7__W`%``!@I___
M;`8``)"G__^`!@``@*C___`&``!@JO__*`<``."J__],!P``(*O__W@'``"`
MK/__[`<``/"Y___4"P``\+W__V0-``!GOO___`T``'"^__\0#@``L+[__T0.
M```0O___D`X``""___^D#@``%``````````!>E(``7P(`1L,!`2(`0``(```
M`!P````4<?__$``````."$8.#$H/"W0$>``_&CLJ,B0B0````$````"@=O__
ME24```!!#@B%`D$.#(<#1`X0A@1!#A2#!48.H`8#?B4*#A1!PPX00<8.#$''
M#@A!Q0X$00L```!@````A````/R;__^S`````$$."(4"00X,AP-!#A"&!$$.
M%(,%3@XP`E$.-$$..$0./$$.0$@.,%<*#A1#PPX00<8.#$''#@A!Q0X$0@M:
M#A1%PPX00<8.#$''#@A!Q0X$````-````.@```!8G/__B@````!!#@B'`D$.
M#(8#0PX0@P1.#B`";@H.$$'##@Q!Q@X(0<<.!$$+``!\````(`$``+"<__\Y
M`@```$$."(4"00X,AP-##A"&!$$.%(,%4`Y,5PY02`Y`60Y,0PY02`Y``D\.
M3$T.4$@.0`)X"@X40<,.$$'&#@Q!QPX(0<4.!$<+`E@.2$$.3$$.4$P.0&D.
M3$L.4$@.0$X.1$$.2$D.3$4.4%`.0````+0```"@`0``<)[__W8!````00X(
MA0)!#@R'`T$.$(8$00X4@P53#J`!;`H.%$'##A!!Q@X,0<<."$'%#@1)"T,.
MK`%!#K`!2`Z@`5\.K`%!#K`!2`Z@`5<.K`%!#K`!:PZL`4$.J`%%#JP!00ZP
M`40.M`%"#K@!0@Z\`4$.P`%(#J0!1`ZH`4$.K`%"#K`!2`Z@`5@.K`%!#K`!
M2`Z@`4,.K`%!#K`!2`Z@`7`.K`%!#K`!4`Z@`0!L````6`(``#B?__^8````
M`$$."(<"00X,A@-##A"#!$X.'$@.($@.%$8.&$$.'$(.($@.$$4*PPX,0\8.
M"$''#@1#"T,.'$(.($X.$$\.'$(.($X.$$\.&$(.'$$.($@.$$;##@Q$Q@X(
M0<<.!```F````,@"``!HG___T`````!!#@B%`D$.#(<#0PX0A@1!#A2#!5$.
MQ"!8#L@@2P[,($$.T"!(#L`@4P[$($$.R"!"#LP@00[0($@.P"!-#LP@0@[0
M($8.U"!!#M@@00[<($$.X"!(#L`@5@H.%$'##A!!Q@X,0<<."$'%#@1$"U$.
MS"!"#M`@2`[$($0.R"!!#LP@00[0($@.P"``+````&0#``"<G___.P````!!
M#@B#`DX.'$@.($P.)$P.*$$.+$$.,$@."$'##@0`2````)0#``"LG___4P``
M``!!#@B&`D$.#(,#3@X<2`X@3@X<0@X@1@X<1PX80@X<00X@00XD1PXH1PXL
M00XP2`X,0<,."$'&#@0``)````#@`P``P)___\D`````00X(A0)!#@R'`T$.
M$(8$00X4@P51#K!`70ZX0$$.O$!!#L!`1P[$0$4.R$!"#LQ`10[00$@.L$!'
M#K1`10ZX0$@.O$!!#L!`2`ZP0$P.O$!!#L!`2`ZP0$D.M$!!#KA`00Z\0$$.
MP$!,#K!`6`H.%$'##A!!Q@X,0<<."$'%#@1+"P`0````=`0``/R?__\%````
M`````/@```"(!```^)___^\!````00X(A0)!#@R'`T$.$(8$00X4@P51#M`@
M;P[8($0.W"!!#N`@2`[0(&T*#A1!PPX00<8.#$''#@A!Q0X$00M##MP@00[@
M($8.W"!!#M@@3P[<($$.X"!(#M`@>0[8($$.W"!!#N`@2`[0($L.W"!!#N`@
M2`[0('4.U"!$#M@@00[<($<.X"!!#N0@10[H($(.["!%#O`@2`[<($8.X"!(
M#M0@1@[8($$.W"!"#N`@2`[0($<.W"!&#N`@3@[0($\.V"!!#MP@0@[@($@.
MT"!6#M@@0@[<($$.X"!(#M`@5`[<($$.X"!(#M`@`!````"$!0``[*#__R(`
M````````;````)@%```(H?__Z`````!!#@B&`D$.#(,#3@X@5@XL00XP3`X@
M8`XL0@XP2`X@3PH.#$'##@A!Q@X$0@M>#BQ!#C!(#B!J#B1!#BA!#BQ'#C!(
M#B!%"@X,0<,."$'&#@1'"T,.#$/##@A!Q@X$`#0````(!@``B*'__]D!````
M00X(AP)!#@R&`T$.$(,$3@Y``W8!"@X00<,.#$'&#@A!QPX$1@L`(````$`&
M```PH___>0````!!#@B#`DX.(&<*#@A!PPX$20L`*````&0&``",H___-```
M``!!#@B#`DX.$$@.'$$.($@.$$D*#@A!PPX$1@MP````D`8``*"C__]:`0``
M`$$."(4"00X,AP-!#A"&!$$.%(,%3@YP`H$.>$0.?$$.@`%,#G`"1@H.%$'#
M#A!!Q@X,0<<."$'%#@1""T,.?$0.@`%L#G1%#GA$#GQ$#H`!1`Z$`4(.B`%"
M#HP!00Z0`4P.<.0#```$!P``C*3__VD-````00X(A0)!#@R'`T$.$(8$00X4
M@P51#M""`@+$#MR"`D$.X(("4`[0@@)##MR"`D$.X(("4`[0@@)H#MR"`D0.
MX(("00[D@@)"#NB"`D(.[(("00[P@@)/#M""`@)`#MR"`D$.X(("3`[0@@("
M0@[<@@)!#N""`DP.T(("4@[<@@)!#N""`DP.T(("?0[<@@)(#N""`DT.Y(("
M3P[H@@)+#NR"`D<.\(("00[T@@)"#OB"`D(._(("10Z`@P)(#MB"`D4.W(("
M1`[@@@)(#M""`DP.W(("3@[@@@),#M2"`D8.V(("1`[<@@)"#N""`DP.T(("
M2P[<@@)$#N""`D8.Y(("2P[H@@)(#NR"`D(.\(("2`[0@@)<"@X40<,.$$'&
M#@Q!QPX(0<4.!$@+4P[8@@)!#MR"`D0.X(("1@[D@@)+#NB"`D@.[(("0@[P
M@@)(#M""`E`.W(("0@[@@@)2#M""`E,.W(("0@[@@@)?#M""`DT.W(("0@[@
M@@)2#M""`E,.W(("00[@@@)?#M""`DL.W(("00[@@@)*#MR"`D$.V(("00[<
M@@)&#N""`D@.T(("30[<@@)!#N""`DX.T((">P[8@@)"#MR"`D$.X(("4`[0
M@@)M#M2"`D$.V(("2@[<@@)$#N""`D<.Y(("0@[H@@)"#NR"`D0.\(("2`[0
M@@)K#MR"`D0.X(("00[D@@)!#NB"`D0.[(("1`[P@@)!#O2"`D(.^(("0@[\
M@@)!#H"#`DP.T(("0P[8@@)%#MR"`D$.X(("3`[0@@)(#MR"`D0.X(("9P[0
M@@).#MR"`D$.X(("7`[0@@)N#MR"`D$.X(("3`[0@@)R#M2"`D(.V(("0@[<
M@@)%#N""`DX.U(("0@[8@@),#MR"`D$.X(("2`[0@@):#M2"`D(.V(("0@[<
M@@)$#N""`@*Q#M""`ET.U(("10[8@@)$#MR"`D0.X(("3`[0@@("E@[4@@)!
M#MB"`D0.W(("00[@@@)<#M""`@,``0[4@@)!#MB"`D$.W(("1`[@@@)3#M""
M`G<.W(("1`[@@@("1`[0@@(#!0(.W(("00[@@@)!#N2"`D(.Z(("0@[L@@)!
M#O""`D\.T(("60[4@@)*#MB"`D0.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)$
M#O""`D@.T(("5P[<@@)!#N""`E(.T(("`MT.U(("0@[8@@)"#MR"`D4.X(("
M3@[4@@)"#MB"`D4.W(("00[@@@),#N2"`D<.Z(("1`[L@@)$#O""`D$.](("
M0@[X@@)"#OR"`D0.@(,"2`[0@@*,`0``[`H``!2N___V`P```$$."(4"00X,
MAP-!#A"&!$$.%(,%3@Y,50Y080Y`50Y,0PY030Y40@Y800Y<00Y@2`Y`=0Y(
M00Y,20Y02`Y`5PY,0PY01PY400Y81`Y<00Y@2`Y`7`Y,0PY01PY40@Y810Y<
M00Y@2`Y`7PY,0PY030Y40@Y800Y<00Y@2`Y`3`Y,10Y03@Y$00Y(00Y,00Y0
M2PY`3PY,0PY030Y40@Y800Y<00Y@2`Y`90Y,20Y02`Y$00Y(10Y,00Y02`Y`
M0PY,0PY06PY`4PY(10Y,00Y02PY`8@H.%$'##A!!Q@X,0<<."$'%#@1("UL.
M3$,.4$D.3$$.2$$.3$$.4$@.0&$.3$8.4$@.0'(.2$$.3$$.4$T.0%4*#D1!
M#DA(#DQ'#E!)"TD.3$X.4%,.0$@.3$,.4$<.5$(.6$$.7$$.8$@.0$D.3$,.
M4$<.5$(.6$$.7$$.8$@.0$P.3$,.4$8.3$$.2$$.3$$.4$@.0$X*#DQ!#E!%
M"T8.1$<.2$(.3$<.4```3````'P,``"$L/__=P````!!#@B'`D$.#(8#00X0
M@P12#AQ!#B!+#A!Z#AA!#AQ!#B!(#A!%"L,.#$'&#@A!QPX$00M!PPX,0\8.
M"$''#@1$````S`P``&1F__]``@```$0,`0!'$`4"=0!&#P-U<`80!P)U?!`&
M`G5X$`,"=70#>P$*P0P!`$'#0<9!QT'%0PP$!$$+```0````%`T``&.P__\$
M`````````#`````H#0``6+#__SP`````00X(@P).#A!-#A1$#AA$#AQ$#B!(
M#@A!PPX$1PX0@P(```!(````7`T``&2P__]=`````$$."(4"00X,AP-!#A"&
M!$$.%(,%3@X@:0XD1`XH1`XL00XP30X@1PX40<,.$$'&#@Q!QPX(0<4.!```
M$````*@-``!XL/__`@`````````8````O`T``'2P__\4`````$$."(,"3@X0
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&`7```0%P``
M``````$````!`````0```-,!```!````(@(```P```#$$0``#0````1?```9
M````T,T``!L````$````&@```-3-```<````!````/7^_V^L`0``!0```/P(
M```&````C`(```H```#J!```"P```!`````5``````````,```#,S@``$0``
M`%0/```2````<`(``!,````(````&`````````#[__]O`0``"/[__V^T#@``
M____;P(```#P__]OY@T``/K__V\%````````````````````````````````
M`````````````````````````-S-````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#P$P``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````30``#_____5&(``$=#0SH@*%5B=6YT=2`U+C,N
M,2TQ-G5B=6YT=3,I(#4N,RXQ(#(P,38P-#(Y`$=#0SH@*%5B=6YT=2`U+C,N
M,2TQ-'5B=6YT=3(I(#4N,RXQ(#(P,38P-#$S```N<VAS=')T86(`+FEN=&5R
M<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N:6YI=``N<&QT`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+FIC<@`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``(```````````````!``````````A````!P````(```"(`0``B`$`
M`"0```````````````0`````````-````/;__V\"````K`$``*P!``#@````
M!0`````````$````!````#X````+`````@```(P"``",`@``<`8```8````!
M````!````!````!&`````P````(```#\"```_`@``.H$``````````````$`
M````````3@```/___V\"````Y@T``.8-``#.````!0`````````"`````@``
M`%L```#^__]O`@```+0.``"T#@``H`````8````"````!`````````!J````
M"0````(```!4#P``5`\``'`"```%``````````0````(````<P````$````&
M````Q!$``,01```C```````````````$`````````'D````!````!@```/`1
M``#P$0``$```````````````$`````0```!^`````0````8`````$@```!(`
M`/`!``````````````@`````````AP````$````&````\!,``/`3```42P``
M```````````0`````````(T````!````!@````1?```$7P``%```````````
M````!`````````"3`````0````(````87P``&%\``+A```````````````0`
M````````FP````$````"````T)\``-"?``#L```````````````$````````
M`*D````!`````@```+R@``"\H```V`T`````````````!`````````"S````
M#@````,```#0S0``T+T```0```````````````0`````````OP````\````#
M````U,T``-2]```$```````````````$`````````,L````!`````P```-C-
M``#8O0``!```````````````!`````````#0````!@````,```#<S0``W+T`
M`/`````&``````````0````(````@@````$````#````S,X``,R^```T`0``
M```````````$````!````-D````!`````P````#0````P```$```````````
M````!`````````#?````"`````,````@T```$,```#00`````````````"``
M````````Y`````$````P`````````!#```!:```````````````!`````0``
I``$````#``````````````!JP```[0```````````````0``````````
